<?php

namespace Drupal\commerce_payment_paw\PluginForm\OffsiteRedirect;

use Drupal\commerce_order\Entity\OrderItemInterface;
use Drupal\commerce_payment\PluginForm\PaymentOffsiteForm as BasePaymentOffsiteForm;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;

class PaymentOffsiteForm extends BasePaymentOffsiteForm
{

	/**
	 * {@inheritdoc}
	 */
	public function buildConfigurationForm(array $form, FormStateInterface $form_state)
	{
		$form = parent::buildConfigurationForm($form, $form_state);

		/** @var \Drupal\commerce_payment\Entity\PaymentInterface $payment */
		$payment = $this->entity;
		/** @var \Drupal\commerce_payment\Plugin\Commerce\PaymentGateway\OffsitePaymentGatewayInterface $payment_gateway_plugin */
		$payment_gateway_plugin = $payment->getPaymentGateway()->getPlugin();

		$configuration = $payment_gateway_plugin->getConfiguration();

		$redirect_method = 'post';
		$redirect_url = ($configuration['mnt_demo'] == true) ? 'https://demo.moneta.ru/assistant.htm' : 'https://www.payanyway.ru/assistant.htm';
		$mnt_id = $configuration['mnt_id'];
		$mnt_amount = number_format($payment->getAmount()->getNumber(), 2, '.', '');
		$mnt_transaction_id = $payment->getOrderId();
		$mnt_currency_code = $payment->getAmount()->getCurrencyCode();
		$mnt_test_mode = ($configuration['mnt_test_mode'] === true) ? '1' : '0';
		if ($payment->getOrder()->getCustomer()->isAnonymous() === false)
		{
			$mnt_description = 'Customer: ' . $payment->getOrder()->getCustomer()->getAccountName();
			$mnt_subscriber_id = $payment->getOrder()->getCustomerId();
		}
		else
		{
			$mnt_description = 'Customer: anonymous';
			$mnt_subscriber_id = '';
		}

		$mnt_signature = md5($mnt_id.$mnt_transaction_id.$mnt_amount.$mnt_currency_code.$mnt_subscriber_id.$mnt_test_mode.$configuration['mnt_secret']);

		$data = [
			'MNT_ID' => $mnt_id,
			'MNT_AMOUNT' => $mnt_amount,
			'MNT_TRANSACTION_ID' => $mnt_transaction_id,
			'MNT_CURRENCY_CODE' => $mnt_currency_code,
			'MNT_TEST_MODE' => $mnt_test_mode,
			'MNT_DESCRIPTION' => $mnt_description,
			'MNT_SUBSCRIBER_ID' => $mnt_subscriber_id,
			'MNT_SIGNATURE' => $mnt_signature,
			'MNT_RETURN_URL' => $form['#return_url'],
			'MNT_FAIL_URL' => $form['#cancel_url']
		];

		return $this->buildRedirectForm($form, $form_state, $redirect_url, $data, $redirect_method);
	}

}
